@@ -14,9 +14,11 @@ testthat::test_that("check_proj4string works as expected", {
 
   # valid numeric
 
-  expect_equal(
-    check_proj4string(3857),
-    "+init=epsg:3857 +proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +no_defs") #nolint
+  expect_true(
+    check_proj4string(3857) %in% c(
+      "+init=epsg:3857 +proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +no_defs", #nolint
+      "+init=epsg:3857 +proj=merc +a=6378137 +b=6378137 +lat_ts=0 +lon_0=0 +x_0=0 +y_0=0 +k=1 +units=m +nadgrids=@null +no_defs") #nolint
+    )
 
 
   # same using CRS
